# friktionless: a powerful Friktion data analysis library for Python

## What is it?

**friktionless** is a Python package providing simplified interfaces to 
Friktion data. It aims to be the fundamental building block for doing 
data engineering and data analysis in Python for Friktion. Additionally, 
it has the broader goal of becoming **the most powerful and flexible open 
source data analysis / manipulation tool available for any protocol**.

## Main Features
Here are just a few of the things that friktionless does (or will do) well:
  - Easy engineering of meaningful performance data about Friktion to enrich
    an analytical data warehouse.
  - Easy dashboarding and portal management for Friktion to manage the 
    growing body of analytics reporting and stakeholder needs.
  - Intuitive python first apis under the hood on everything - we're building 
    on top of pandas, altair, seaborn, and other popular python tools so the 
    community is enabled.
  - a Python and CLI api to enable data scientists and data engineers off the 
    same, singular codebase.

## Where to get it
The source code is currently hosted on GitHub at:
https://github.com/Friktion-Labs/friktionless

Binary installers for the latest released version are available at the [Python
Package Index (PyPI)](https://pypi.org/project/friktionless)

```sh
#PyPI
pip install friktionless
```

# License
TBA

# Documentation
TBA

# Background
Work on ``friktionless`` began as an abstraction designed by a few early DAO contributors and was quickly adopted by the core team as a mechanism to power up the team and enable the community greater ownership of their Friktion data.